@@ -11,7 +11,6 @@
 
 import re
 import json
-from operator import itemgetter
 
 from nektar import Waggle
 from emoji import emoji_list
@@ -42,7 +41,7 @@ RE_LINKS_RIGHT = re.compile(r"\]\([^\)]+\)")
 RE_BLOCKQUOTES = re.compile(r">[\ ]?")
 RE_HR = re.compile(r"--[\-]+")
 RE_TRAILING_PARENTHESIS = re.compile(r"[\(\[\{\}\]\)]")
-RE_USER_TAGS = re.compile(r"[\s]*@[a-z0-9\-\.]{3,16}[,\s]")
+RE_USER_TAGS = re.compile(r"[^\w\/]@[\w\-\.]{3,16}[^\w\/]")
 RE_NON_ASCII = re.compile(r"[^ -~]")
 
 STOP_WORDS = [
@@ -1344,12 +1343,14 @@ def _analyze_title(title, keywords, full=False):
 
     bmin = length < 20
     amax = length > 80
+    
 
     score = 0
     skeywords = 0
     readability = 0
 
-    if length:
+    emojis = emoji_list(title)
+    if length and not len(emojis):
         uppercase = len(RE_UPPERCASE.findall(cleaned))/length
         adjust = (1, 0.5)[int(bool(uppercase>0.5))]
         english = _to_english(cleaned, chars=True)
@@ -1375,6 +1376,7 @@ def _analyze_title(title, keywords, full=False):
         "keywords": keywords,
         "readability": readability,
         "keyword_score": skeywords,
+        "emojis": emojis,
         "score": score,
     }
 
@@ -1392,7 +1394,7 @@ def get_keywords(body, occurrence=4):
         if count < occurrence:
             continue
         keywords[word] = count
-    return dict(sorted(keywords.items(), key=itemgetter(1), reverse=True))
+    return keywords
 
 def get_bigrams(body, occurrence=4):
     occurrence = int(occurrence)
